@@ -1,3 +1,6 @@
+import pyHPump.util as util
+
+
 class PSD:
     # default address in case that psd has address pin set on 0
     asciiAddress = "1"
@@ -5,7 +8,7 @@ class PSD:
     baudRate = 9600
     # standard resolution has value 0 = 3000 steps
     resolutionMode = 0
-    # type of PSD: 4 or 6, most used is psd4
+    # type of PSD: 4 / 6 / 4sf / 6sf, most used is psd4
     type = 4
 
     def __init__(self, address: str, type=4, baudRate=9600, resolutionMode=0):
