@@ -33,4 +33,13 @@ class PositionInShortestDirection(Enum):
     WASH = 3
     RETURN = 4
     BYPASS = 5
-    EXTRA = 6
\ No newline at end of file
+    EXTRA = 6
+
+
+class PSDTypes(Enum):
+    PSD4 = '4'
+    PSD6 = '6'
+    PSD4_SMOOTH_FLOW = '4sf'
+    PSD6_SMOOTH_FLOW = '6sf'
+
+
